==> riskservice-client-1.4.4-sources.jar: cn/fraudmetrix/riskservice/ruledetail/SuspectTeamDetail.java <==
package cn.fraudmetrix.riskservice.ruledetail;

/**
 * Created by qiangzi on 17/2/8.
 */
public class SuspectTeamDetail extends ConditionDetail {

    private String dimType;
    private String dimValue;
    private String groupId;
    private Integer totalCnt;
    private Integer blackCnt;
    private Integer greyCnt;
    private String nodeDist;
    private String fraudDist;
    private String blackRat; //群体节点内风险名单的节点占比(#0.00%)
    private String greyRat;  //群体节点内关注名单的节点占比(#0.00%)
    private Integer degree; //一度关联节点个数
    private Integer totalCntTwo; //二度关联节点个数
    private Integer blackCntOne; //一度关联风险节点个数
    private Integer blackCntTwo; //二度关联风险节点个数
    private Integer blackDst; //风险节点距离（3度之内）
    private Integer coreDst; //核心节点距离
    private Boolean coreNode; //是否核心节点
    private String nodeDistJson; //群体节点类型分布
    private String fraudDistOne; //一度风险名单分布
    private String fraudDistTwo; //二度风险名单分布

    public SuspectTeamDetail() {
        super("suspected_team");
    }


    public String getDimType() {
        return dimType;
    }

    public void setDimType(String dimType) {
        this.dimType = dimType;
    }

    public String getDimValue() {
        return dimValue;
    }

    public void setDimValue(String dimValue) {
        this.dimValue = dimValue;
    }


    public String getGroupId() {
        return groupId;
    }

    public void setGroupId(String groupId) {
        this.groupId = groupId;
    }

    public Integer getTotalCnt() {
        return totalCnt;
    }

    public void setTotalCnt(Integer totalCnt) {
        this.totalCnt = totalCnt;
    }

    public Integer getBlackCnt() {
        return blackCnt;
    }

    public void setBlackCnt(Integer blackCnt) {
        this.blackCnt = blackCnt;
    }

    public Integer getGreyCnt() {
        return greyCnt;
    }

    public void setGreyCnt(Integer greyCnt) {
        this.greyCnt = greyCnt;
    }

    public String getNodeDist() {
        return nodeDist;
    }

    public void setNodeDist(String nodeDist) {
        this.nodeDist = nodeDist;
    }

    public String getFraudDist() {
        return fraudDist;
    }

    public void setFraudDist(String fraudDist) {
        this.fraudDist = fraudDist;
    }

    public String getBlackRat() {
        return blackRat;
    }

    public void setBlackRat(String blackRat) {
        this.blackRat = blackRat;
    }

    public String getGreyRat() {
        return greyRat;
    }

    public void setGreyRat(String greyRat) {
        this.greyRat = greyRat;
    }

    public Integer getDegree() {
        return degree;
    }

    public void setDegree(Integer degree) {
        this.degree = degree;
    }

    public Integer getTotalCntTwo() {
        return totalCntTwo;
    }

    public void setTotalCntTwo(Integer totalCntTwo) {
        this.totalCntTwo = totalCntTwo;
    }

    public Integer getBlackCntOne() {
        return blackCntOne;
    }

    public void setBlackCntOne(Integer blackCntOne) {
        this.blackCntOne = blackCntOne;
    }

    public Integer getBlackCntTwo() {
        return blackCntTwo;
    }

    public void setBlackCntTwo(Integer blackCntTwo) {
        this.blackCntTwo = blackCntTwo;
    }

    public Integer getBlackDst() {
        return blackDst;
    }

    public void setBlackDst(Integer blackDst) {
        this.blackDst = blackDst;
    }

    public Integer getCoreDst() {
        return coreDst;
    }

    public void setCoreDst(Integer coreDst) {
        this.coreDst = coreDst;
    }

    public Boolean getCoreNode() {
        return coreNode;
    }

    public void setCoreNode(Boolean coreNode) {
        this.coreNode = coreNode;
    }

    public String getNodeDistJson() {
        return nodeDistJson;
    }

    public void setNodeDistJson(String nodeDistJson) {
        this.nodeDistJson = nodeDistJson;
    }

    public String getFraudDistOne() {
        return fraudDistOne;
    }

    public void setFraudDistOne(String fraudDistOne) {
        this.fraudDistOne = fraudDistOne;
    }

    public String getFraudDistTwo() {
        return fraudDistTwo;
    }

    public void setFraudDistTwo(String fraudDistTwo) {
        this.fraudDistTwo = fraudDistTwo;
    }
}

==> riskservice-client-1.4.8-sources.jar: cn/fraudmetrix/riskservice/ruledetail/SuspectTeamDetail.java <==
package cn.fraudmetrix.riskservice.ruledetail;

/**
 * Created by qiangzi on 17/2/8.
 */
public class SuspectTeamDetail extends ConditionDetail {

    private String dimType;
    private String dimValue;
    private String groupId;
    private Integer totalCnt;
    private Integer blackCnt;
    private Integer greyCnt;
    private String nodeDist;
    private String fraudDist;
    private String blackRat; //群体节点内风险名单的节点占比(#0.00%)
    private String greyRat;  //群体节点内关注名单的节点占比(#0.00%)
    private Integer degree; //一度关联节点个数
    private Integer totalCntTwo; //二度关联节点个数
    private Integer blackCntOne; //一度关联风险节点个数
    private Integer blackCntTwo; //二度关联风险节点个数
    private Integer blackDst; //风险节点距离（3度之内）
    private Integer coreDst; //核心节点距离
    private Boolean coreNode; //是否核心节点
    private String nodeDistJson; //群体节点类型分布
    private String fraudDistOne; //一度风险名单分布
    private String fraudDistTwo; //二度风险名单分布
    private Integer nodeScore; //关联风险分

    public SuspectTeamDetail() {
        super("suspected_team");
    }


    public String getDimType() {
        return dimType;
    }

    public void setDimType(String dimType) {
        this.dimType = dimType;
    }

    public String getDimValue() {
        return dimValue;
    }

    public void setDimValue(String dimValue) {
        this.dimValue = dimValue;
    }


    public String getGroupId() {
        return groupId;
    }

    public void setGroupId(String groupId) {
        this.groupId = groupId;
    }

    public Integer getTotalCnt() {
        return totalCnt;
    }

    public void setTotalCnt(Integer totalCnt) {
        this.totalCnt = totalCnt;
    }

    public Integer getBlackCnt() {
        return blackCnt;
    }

    public void setBlackCnt(Integer blackCnt) {
        this.blackCnt = blackCnt;
    }

    public Integer getGreyCnt() {
        return greyCnt;
    }

    public void setGreyCnt(Integer greyCnt) {
        this.greyCnt = greyCnt;
    }

    public String getNodeDist() {
        return nodeDist;
    }

    public void setNodeDist(String nodeDist) {
        this.nodeDist = nodeDist;
    }

    public String getFraudDist() {
        return fraudDist;
    }

    public void setFraudDist(String fraudDist) {
        this.fraudDist = fraudDist;
    }

    public String getBlackRat() {
        return blackRat;
    }

    public void setBlackRat(String blackRat) {
        this.blackRat = blackRat;
    }

    public String getGreyRat() {
        return greyRat;
    }

    public void setGreyRat(String greyRat) {
        this.greyRat = greyRat;
    }

    public Integer getDegree() {
        return degree;
    }

    public void setDegree(Integer degree) {
        this.degree = degree;
    }

    public Integer getTotalCntTwo() {
        return totalCntTwo;
    }

    public void setTotalCntTwo(Integer totalCntTwo) {
        this.totalCntTwo = totalCntTwo;
    }

    public Integer getBlackCntOne() {
        return blackCntOne;
    }

    public void setBlackCntOne(Integer blackCntOne) {
        this.blackCntOne = blackCntOne;
    }

    public Integer getBlackCntTwo() {
        return blackCntTwo;
    }

    public void setBlackCntTwo(Integer blackCntTwo) {
        this.blackCntTwo = blackCntTwo;
    }

    public Integer getBlackDst() {
        return blackDst;
    }

    public void setBlackDst(Integer blackDst) {
        this.blackDst = blackDst;
    }

    public Integer getCoreDst() {
        return coreDst;
    }

    public void setCoreDst(Integer coreDst) {
        this.coreDst = coreDst;
    }

    public Boolean getCoreNode() {
        return coreNode;
    }

    public void setCoreNode(Boolean coreNode) {
        this.coreNode = coreNode;
    }

    public String getNodeDistJson() {
        return nodeDistJson;
    }

    public void setNodeDistJson(String nodeDistJson) {
        this.nodeDistJson = nodeDistJson;
    }

    public String getFraudDistOne() {
        return fraudDistOne;
    }

    public void setFraudDistOne(String fraudDistOne) {
        this.fraudDistOne = fraudDistOne;
    }

    public String getFraudDistTwo() {
        return fraudDistTwo;
    }

    public void setFraudDistTwo(String fraudDistTwo) {
        this.fraudDistTwo = fraudDistTwo;
    }

    public Integer getNodeScore() {
        return nodeScore;
    }

    public void setNodeScore(Integer nodeScore) {
        this.nodeScore = nodeScore;
    }
}
